package testtcf.handlers;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import org.eclipse.tcf.internal.debug.model.TCFLaunch;
import org.eclipse.tcf.protocol.IChannel;
import org.eclipse.tcf.protocol.IToken;
import org.eclipse.tcf.services.IBreakpoints;
import org.eclipse.tcf.services.IBreakpoints.DoneCommand;
import org.eclipse.tcf.services.IRunControl;
import org.eclipse.tcf.services.IRunControl.RunControlContext;

public class TCFLaunchListener implements org.eclipse.tcf.services.IRunControl.RunControlListener {
	
	private Map<String, RunControlContext> m_runControlContexts = new HashMap<String, RunControlContext>();

	private TCFLaunch m_tcfLaunch = null;
	
	private IBreakpoints m_breakpoints = null;
	
	public TCFLaunchListener(final TCFLaunch tcfLaunch) {
		this.m_tcfLaunch = tcfLaunch;
		IChannel channel = this.m_tcfLaunch.getChannel();
		if ((channel != null) && (channel.getState() == IChannel.STATE_OPEN)) {
			IRunControl runControl = channel.getRemoteService(IRunControl.class);
			runControl.addListener(this);
		}
		
	}

	private void printContexts(final RunControlContext[] contexts) {
		for (RunControlContext runControlContext : contexts) {

			final String id = runControlContext.getID();
			final String name = runControlContext.getName();			
			System.out.print("id: " + id + " name: " + name + " ");
			
			m_runControlContexts.put(id, runControlContext);
			
		}
		System.out.print("\n");
	}
	

	@Override
	public void contextAdded(RunControlContext[] contexts) {
		System.out.print("contextAdded: ");
		printContexts(contexts);
		for (RunControlContext runControlContext : contexts) {
			this.m_runControlContexts.put(runControlContext.getID(), runControlContext);
		}
	}

	@Override
	public void contextChanged(RunControlContext[] contexts) {
		System.out.print("contextChanged: ");
		printContexts(contexts);
	}

	@Override
	public void contextRemoved(String[] context_ids) {
		System.out.print("contextRemoved: ");
		for (String id : context_ids) {
			System.out.println("id: " + id + " ");
		}
		System.out.print("\n");
		for (String id : context_ids) {
			this.m_runControlContexts.remove(id);
		}		
	}

	@Override
	public void contextSuspended(String context, String pc, String reason, Map<String, Object> params) {
		System.out.println("contextSuspended: context: " + context + " pc: " + pc + " reason: " + reason);		
	}

	@Override
	public void contextResumed(String context) {
		System.out.println("contextResumed: context: " + context);		
	}

	@Override
	public void containerSuspended(String context, String pc, String reason, Map<String, Object> params,
			String[] suspended_ids) {
		System.out.print("containerSuspended: context: " + context + " pc: " + pc + " reason: " + reason + " ");
		for (String id : suspended_ids) {
			System.out.print(" id: " + id + " ");
		}
		System.out.print("\n");
	}

	@Override
	public void containerResumed(String[] context_ids) {
		System.out.print("containerResumed: ");
		for (String id : context_ids) {
			System.out.print(" id: " + id + " ");
		}
		System.out.print("\n");
	}

	@Override
	public void contextException(String context, String msg) {
		System.out.println("contextException: context: " + context + " msg: " + msg);		
	}			
}
